@@ -37,20 +37,21 @@ function el(tag, attrs, children) {
 }
 
 function render(list, data) {
-  var poweredLink = document.querySelector('#fx-name')
-  poweredLink.innerHTML = data.meta.name + '@' + data.meta.version
-  poweredLink.setAttribute('href', data.meta.url + '?from=dist&version=' + data.meta.version)
   document.title = 'Table of APIs - ' + data.name
-  document.querySelector('#app-name').innerHTML = data.name
+  $('#app-name').html(data.name)
+
+  var poweredLink = $('#fx-name')
+  poweredLink.html(data.meta.name + '@' + data.meta.version)
+  poweredLink.attr('href', data.meta.url + '?from=dist&version=' + data.meta.version)
   var s = localStorage.getItem('options-expanded')
   if (s !== undefined && s !== null && s !== '') {
     data.expanded = s === '1'
   }
-  document.querySelector('#expanded-on-load').checked = data.expanded
+  $('#expanded-on-load').prop('checked', data.expanded)
 
   var routes = data.routes
   if (!routes || !routes.length) {
-    document.querySelector('#loading').innerHTML = '未找到接口信息'
+    $('#loading').html('未找到接口信息')
     return
   }
 
@@ -89,8 +90,7 @@ function render(list, data) {
     modules: modules
   }
 
-  list.innerHTML = ''
-  list.appendChild(apiList)
+  list.empty().append(apiList)
 }
 
 function padStart(str, width, fill) {
@@ -195,7 +195,7 @@ function renderUrlInfo(route) {
 
 function getArgValueString(value, editable) {
   if (value === null || value === undefined) {
-    return editable ? '' : 'None'
+    return editable ? '' : 'null'
   }
 
   if (typeof value === 'number') {
@@ -203,10 +203,7 @@ function getArgValueString(value, editable) {
   }
 
   if (typeof value === 'boolean') {
-    if (editable) {
-      return value ? 'true' : 'false'
-    }
-    return value ? 'True' : 'False'
+    return value ? 'true' : 'false'
   }
 
   if (typeof value === 'string') {
@@ -235,7 +232,7 @@ function getArgDefaultValue(arg, editable) {
 
 function renderArgDefaultValue(arg) {
   if (!arg.has_default) {
-    return arg.annotation_name === 'HttpRequest' ? el('span', null, '-') : el('span', {
+    return el('span', {
       'class': 'required-field',
       title: '必填项'
     }, '*')
@@ -277,9 +274,14 @@ function renderArg(arg, editable) {
   if (arg.is_variable) {
     arg.has_annotation = true
     argName = '**' + argName
-    argType = 'VAR_KEYWORD'
+    argType = 'variable'
   } else if (arg.has_annotation) {
     argType = arg.annotation_name
+    if (argType === 'str') {
+      argType = 'string'
+    } else if (argType === 'HttpFile') {
+      argType = 'file'
+    }
   } else {
     argType = '-'
   }
@@ -300,8 +302,7 @@ function renderArg(arg, editable) {
     el(
       'td',
       null,
-      editable && arg.annotation_name !== 'HttpRequest' && !arg.is_variable ?
-        renderArgEditor(arg) : renderArgDefaultValue(arg)
+      editable && !arg.is_variable ? renderArgEditor(arg) : renderArgDefaultValue(arg)
     ),
     el(
       'td',
@@ -327,11 +328,7 @@ function renderArgs(args, editable, append) {
 
   var rows = args.filter(function (arg) {
     // 编辑时不渲染 可变参数
-    if (editable && arg.is_variable) {
-      return false
-    }
-    // 始终不显示 HttpRequest 参数 和 注入参数
-    return arg.annotation_name !== 'HttpRequest' && !arg.is_injected
+    return !editable || !arg.is_variable
   }).map(function (arg) {
     return renderArg(arg, editable)
   })
@@ -370,7 +367,7 @@ function renderReturn(route) {
   return el('p', {'class': 'return-info'}, [
     el('span', null, '返回'),
     // route.handler_info.return_type ? el('code', null, route.return_type) : '',
-    el('span', null, ':'),
+    el('span', null, ': '),
     el('span', {'class': 'comment'}, route.handler_info.return_description || '-')
   ])
 }
