@@ -7,6 +7,7 @@ from ..http import HttpRequest, HttpServerError
 from ..http import HttpResponse, HttpBadRequest, JsonResponse
 from ..middleware import MiddlewareManager
 from ..routes.meta import RouteMeta
+from ..session import HttpSession
 from ..util.func_util import ArgumentSpecification, get_func_info
 
 
@@ -22,32 +23,32 @@ def route(module=None, name=None, extname=None, **kwargs):
     :param extname: 给路径指定一个扩展名，不能包含 . 符号
     """
 
-    def invoke_route(func):
-        @wraps(func)
+    def invoke_route(handler):
+        @wraps(handler)
         def caller(*args):
             # 参数长度不为 2 时，认为是用户调用
             if len(args) != 2:
-                return func(*args)
+                return handler(*args)
 
             # Http 请求对象
             # :type HttpRequest
             request = args[0]
             # 函数声明时定义的参数列表
             # :type OrderedDict
-            func_args = args[1]
+            handler_args = args[1]
 
             # 如果传入的参数第一个不是 request，第二个不是 OrderedDict，
             # 那么就认为是用户调用，而不是路由调用
-            # 此时直接将原参数传给 func 进行调用
-            if not isinstance(request, HttpRequest) or not isinstance(func_args, OrderedDict):
-                return func(*args)
+            # 此时直接将原参数传给 handler 进行调用
+            if not isinstance(request, HttpRequest) or not isinstance(handler_args, OrderedDict):
+                return handler(*args)
 
             context = AppContext.get(request.app_id)
 
             meta = RouteMeta(
-                func,
-                func_args,
-                route_id='%s_%s' % (func.__module__.replace('_', '__').replace('.', '_'), func.__name__),
+                handler,
+                handler_args,
+                route_id='%s_%s' % (handler.__module__.replace('_', '__').replace('.', '_'), handler.__name__),
                 module=module,
                 name=name,
                 extname=extname,
@@ -69,7 +70,7 @@ def _invoke_with_route(request: HttpRequest, meta: RouteMeta, context: AppContex
         meta
     )
 
-    func_args = meta.func_args
+    handler_args = meta.handler_args
     func = meta.handler
 
     # 调用中间件，以处理请求
@@ -91,7 +92,7 @@ def _invoke_with_route(request: HttpRequest, meta: RouteMeta, context: AppContex
     # 有参数，自动从 queryString, POST 或 json 中获取
     # 匹配参数
 
-    actual_args = _get_actual_args(request, func, func_args, context)
+    actual_args = _get_actual_args(request, func, handler_args, context)
 
     result = mgr.before_invoke(actual_args)
 
@@ -104,7 +105,7 @@ def _invoke_with_route(request: HttpRequest, meta: RouteMeta, context: AppContex
         return mgr.handle_response(_wrap_http_response(mgr, result))
 
     # 调用路由函数
-    arg_len = len(func_args)
+    arg_len = len(handler_args)
     if arg_len == 0:
         return mgr.handle_response(_wrap_http_response(mgr, func()))
 
@@ -138,7 +139,7 @@ def _process_json_params(request: HttpRequest, context: AppContext):
     try:
         request.BODY = json.loads(body.decode())
     except Exception as e:
-        context.logger.warning('Deserialize request body failed: %s' % str(e))
+        context.logger.warning('Failed to deserialize request body: %s' % str(e))
 
 
 def _get_parameter_str(args: OrderedDict):
@@ -201,7 +202,7 @@ def _get_actual_args(request: HttpRequest, func, args: OrderedDict, context: App
     for arg_name in args.keys():
         arg_spec = args.get(arg_name)
 
-        if arg_spec.is_injected:
+        if arg_spec.is_injection:
             injection_args.append(arg_name)
             used_args.append(arg_name)
             continue
@@ -212,7 +213,7 @@ def _get_actual_args(request: HttpRequest, func, args: OrderedDict, context: App
             has_variable_args = True
             continue
 
-        # 以及情况将传入 HttpRequest 对象
+        # 以下情况将传入 HttpRequest 对象
         # 1. 当参数名称是 request 并且未指定类型
         # 2. 当参数类型是 HttpRequest 时 (不论参数名称，包括 request)
         # 但是，参数名称是 request 但其类型不是 HttpRequest ，就会被当作一般参数处理
@@ -223,19 +224,38 @@ def _get_actual_args(request: HttpRequest, func, args: OrderedDict, context: App
             actual_args[arg_name] = request
             continue
 
+        # 以下情况将传入 HttpSession 对象
+        # 1. 当参数名称是 session 并且未指定类型
+        # 2. 当参数类型是 HttpSession 时 (不论参数名称，包括 session)
+        # 但是，参数名称是 session 但其类型不是 HttpSession ，就会被当作一般参数处理
+        is_session = False
+        if arg_name == 'request' and not arg_spec.has_annotation:
+            is_session = True
+        elif arg_spec.annotation == HttpSession:
+            is_session = True
+
+        if is_session:
+            if request.session is None:
+                msg = '%s\n\tParameter "%s" of type "HttpSession" is not available, ' \
+                      'the value will always be "None", ' \
+                      'please make sure that you have registered the Session-Middleware correctly, ' \
+                      'Parameters: (%s)' % (
+                          get_func_info(func),
+                          arg_name,
+                          _get_parameter_str(args)
+                      )
+                context.logger.warning(msg)
+            # 在 session 未启用时，其值为 None
+            actual_args[arg_name] = request.session
+            continue
+
         # noinspection PyUnresolvedReferences
         use_default, arg_value = _get_value(arg_source, arg_name, arg_spec, request.BODY, request.FILES)
 
         # 未找到参数
         if use_default is None:
-            msg = '%s\n\tMissing required argument "%s", Parameters: (%s)' % (
-                get_func_info(func),
-                arg_name,
-                _get_parameter_str(args)
-            )
+            msg = 'Missing required argument "%s".' % arg_name
             context.logger.warning(msg)
-            if not context.debug:
-                msg = 'Missing required argument'
             return HttpBadRequest(msg)
 
         # 使用默认值
@@ -271,14 +291,16 @@ def _get_actual_args(request: HttpRequest, func, args: OrderedDict, context: App
             if arg_value == 'true':
                 actual_args[arg_name] = True
                 used_args.append(arg_name)
-            elif arg_value == 'false':
+                continue
+            if arg_value == 'false':
                 actual_args[arg_name] = False
                 used_args.append(arg_name)
-            else:
-                context.logger.error(
-                    'Value for "%s!%s" may be incorrect (a boolean value expected: true/false): %s' % (
-                        func.__name__, arg_name, arg_value))
-            continue
+                continue
+
+            msg = 'Cannot parse value "%s" into type "%s". (expected: true/false)' % (
+                (arg_value, arg_spec.annotation_name))
+            context.logger.warning(msg)
+            return HttpBadRequest(msg)
 
         # 转换失败时，会抛出异常
         # noinspection PyBroadException
@@ -290,24 +312,22 @@ def _get_actual_args(request: HttpRequest, func, args: OrderedDict, context: App
                     arg_value = json.loads(arg_value)
                 except Exception:
                     # 此处的异常直接忽略即可
-                    context.logger.warning(
-                        'Value for "%s!%s" may be incorrect: %s' % (func.__name__, arg_name, arg_value))
+                    msg = 'Cannot parse value "%s" into type "%s".' % (arg_value, arg_spec.annotation_name)
+                    context.logger.warning(msg)
+                    return HttpBadRequest(msg)
 
-                # 类型一致，直接使用
-                if isinstance(arg_value, arg_spec.annotation):
-                    # 如果原始声明是 tuple 类型，那么把 list 转换成 tuple
-                    # 虽然在发起请求的时候并不能指定为 tuple，但还是想兼容一下
-                    actual_args[arg_name] = tuple(arg_value) if arg_spec.is_tuple else arg_value
-                    used_args.append(arg_name)
-                    continue
+            # 类型一致，直接使用
+            if isinstance(arg_value, arg_spec.annotation):
+                # 如果原始声明是 tuple 类型，那么把 list 转换成 tuple
+                # 虽然在发起请求的时候并不能指定为 tuple，但还是想兼容一下
+                actual_args[arg_name] = tuple(arg_value) if arg_spec.is_tuple else arg_value
+                used_args.append(arg_name)
+                continue
             actual_args[arg_name] = arg_spec.annotation(arg_value)
             used_args.append(arg_name)
         except Exception:
-            msg = 'Argument type of "%s" mismatch, expect type "%s" but got "%s", Parameters: (%s)' \
-                  % (arg_name, arg_spec.annotation.__name__, type(arg_value).__name__, _get_parameter_str(args))
+            msg = 'Cannot parse value "%s" into type "%s".' % (arg_value, arg_spec.annotation_name)
             context.logger.warning(msg)
-            if not context.debug:
-                msg = 'Argument type mismatch'
             return HttpBadRequest(msg)
 
     # 填充注入参数
@@ -320,7 +340,7 @@ def _get_actual_args(request: HttpRequest, func, args: OrderedDict, context: App
         elif injection_name in context.injections:
             actual_args[arg_name] = context.injections[injection_name]
         else:
-            msg = 'Injection name "%s" not found' % injection_name
+            msg = 'Injection name "%s" not found.' % injection_name
             context.logger.warning(msg)
             return HttpServerError(msg) if context.debug else HttpServerError()
 
@@ -357,11 +377,11 @@ def _get_actual_args(request: HttpRequest, func, args: OrderedDict, context: App
 
     # 启用了严格模式
     # 返回 400 响应
-    msg = 'Unknown argument(s) found: "%s", Parameters: (%s)' \
+    msg = 'Unknown argument(s) found: "%s", Parameters: (%s).' \
           % (','.join(variable_arg_keys), _get_parameter_str(args))
     context.logger.warning(msg)
     if not context.debug:
-        msg = 'Unknown argument(s)'
+        msg = 'Unknown argument(s) found: %s.' % ','.join(variable_arg_keys)
     return HttpBadRequest(msg)
 
 
